==> gradle-6.2-src.zip: gradle-6.2/subprojects/platform-native/platform-native.gradle.kts <==
/*
 * Copyright 2011 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import org.gradle.gradlebuild.unittestandcompile.ModuleType

plugins {
    `java-library`
    gradlebuild.`strict-compile`
    gradlebuild.classycle
}

dependencies {
    implementation(project(":baseServices"))
    implementation(project(":logging"))
    implementation(project(":native"))
    implementation(project(":processServices"))
    implementation(project(":fileCollections"))
    implementation(project(":coreApi"))
    implementation(project(":modelCore"))
    implementation(project(":core"))
    implementation(project(":workers"))
    implementation(project(":platformBase"))
    implementation(project(":diagnostics"))

    implementation(library("nativePlatform"))
    implementation(library("groovy"))
    implementation(library("slf4j_api"))
    implementation(library("guava"))
    implementation(library("commons_lang"))
    implementation(library("commons_io"))
    implementation(library("snakeyaml"))
    implementation(library("gson"))
    implementation(library("inject"))

    testRuntimeOnly(project(":runtimeApiInfo"))

    integTestRuntimeOnly(project(":maven"))
    // Required to test visual studio project file generation for generated sources
    integTestRuntimeOnly(project(":ideNative"))

    testFixturesApi(project(":resources"))
    testFixturesApi(testFixtures(project(":ide")))
    testFixturesImplementation(testFixtures(project(":core")))
    testFixturesImplementation(project(":internalTesting"))
    testFixturesImplementation(project(":internalIntegTesting"))
    testFixturesImplementation(project(":native"))
    testFixturesImplementation(project(":platformBase"))
    testFixturesImplementation(project(":fileCollections"))
    testFixturesImplementation(project(":processServices"))
    testFixturesImplementation(project(":snapshots"))
    testFixturesImplementation(library("guava"))
    testFixturesImplementation(library("nativePlatform"))
    testFixturesImplementation(library("commons_lang"))
    testFixturesImplementation(library("commons_io"))

    testImplementation(testFixtures(project(":core")))
    testImplementation(testFixtures(project(":messaging")))
    testImplementation(testFixtures(project(":platformBase")))
    testImplementation(testFixtures(project(":modelCore")))
    testImplementation(testFixtures(project(":diagnostics")))
    testImplementation(testFixtures(project(":baseServices")))
    testImplementation(testFixtures(project(":snapshots")))
}

gradlebuildJava {
    moduleType = ModuleType.CORE
}

classycle {
    excludePatterns.set(listOf(
        "org/gradle/nativeplatform/plugins/**",
        "org/gradle/nativeplatform/tasks/**",
        "org/gradle/nativeplatform/internal/resolve/**",
        "org/gradle/nativeplatform/toolchain/internal/**"
    ))
}

==> gradle-6.6.1-src.zip: gradle-6.6.1/subprojects/platform-native/platform-native.gradle.kts <==
/*
 * Copyright 2011 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import org.gradle.gradlebuild.test.integrationtests.integrationTestUsesSampleDir
plugins {
    gradlebuild.distribution.`api-java`
}

dependencies {
    implementation(project(":baseServices"))
    implementation(project(":logging"))
    implementation(project(":native"))
    implementation(project(":processServices"))
    implementation(project(":fileCollections"))
    implementation(project(":coreApi"))
    implementation(project(":modelCore"))
    implementation(project(":core"))
    implementation(project(":workers"))
    implementation(project(":platformBase"))
    implementation(project(":diagnostics"))

    implementation(library("nativePlatform"))
    implementation(library("groovy"))
    implementation(library("slf4j_api"))
    implementation(library("guava"))
    implementation(library("commons_lang"))
    implementation(library("commons_io"))
    implementation(library("snakeyaml"))
    implementation(library("gson"))
    implementation(library("inject"))

    testFixturesApi(project(":resources"))
    testFixturesApi(testFixtures(project(":ide")))
    testFixturesImplementation(testFixtures(project(":core")))
    testFixturesImplementation(project(":internalIntegTesting"))
    testFixturesImplementation(project(":native"))
    testFixturesImplementation(project(":platformBase"))
    testFixturesImplementation(project(":fileCollections"))
    testFixturesImplementation(project(":processServices"))
    testFixturesImplementation(project(":snapshots"))
    testFixturesImplementation(library("guava"))
    testFixturesImplementation(library("nativePlatform"))
    testFixturesImplementation(library("commons_lang"))
    testFixturesImplementation(library("commons_io"))

    testImplementation(testFixtures(project(":core")))
    testImplementation(testFixtures(project(":messaging")))
    testImplementation(testFixtures(project(":platformBase")))
    testImplementation(testFixtures(project(":modelCore")))
    testImplementation(testFixtures(project(":diagnostics")))
    testImplementation(testFixtures(project(":baseServices")))
    testImplementation(testFixtures(project(":snapshots")))

    testRuntimeOnly(project(":distributionsCore")) {
        because("ProjectBuilder tests load services from a Gradle distribution.")
    }
    integTestDistributionRuntimeOnly(project(":distributionsNative")) {
        because("Required 'ideNative' to test visual studio project file generation for generated sources")
    }
}

classycle {
    excludePatterns.set(listOf(
        "org/gradle/nativeplatform/plugins/**",
        "org/gradle/nativeplatform/tasks/**",
        "org/gradle/nativeplatform/internal/resolve/**",
        "org/gradle/nativeplatform/toolchain/internal/**"
    ))
}

integrationTestUsesSampleDir("subprojects/platform-native/src/main")
